@@ -1,7 +1,7 @@
 $TESTING = true
 
-require 'composite_sexp_processor'
-require 'minitest/autorun'
+require "composite_sexp_processor"
+require "minitest/autorun"
 
 class FakeProcessor1 < SexpProcessor # ZenTest SKIP
 
@@ -9,16 +9,13 @@ class FakeProcessor1 < SexpProcessor # ZenTest SKIP
     super
     self.warn_on_default = false
     self.default_method = :default_processor
+    self.require_empty = false
     self.expected = Array
   end
 
-  def default_processor(exp)
-    result = []
-    result << exp.shift
-    until exp.empty? do
-      result << exp.shift.to_s + " woot"
-    end
-    result
+  def default_processor exp
+    t, *rest = exp
+    s(t, *rest.map { |s| "#{s} woot" })
   end
 end
 
@@ -29,20 +26,20 @@ class TestCompositeSexpProcessor < Minitest::Test
   end
 
   def test_process_default
-    data = [1, 2, 3]
+    data = s(1, 2, 3)
     result = @p.process(data.dup)
     assert_equal(data.dup, result)
   end
 
   def test_process_fake1
-    data = [:x, 1, 2, 3]
+    data = s(:x, 1, 2, 3)
     @p << FakeProcessor1.new
     result = @p.process(data.dup)
     assert_equal [:x, "1 woot", "2 woot", "3 woot"], result
   end
 
   def test_process_fake1_twice
-    data = [:x, 1, 2, 3]
+    data = s(:x, 1, 2, 3)
     @p << FakeProcessor1.new
     @p << FakeProcessor1.new
     result = @p.process(data.dup)
